# -*- coding: utf-8 -*-
from django.conf import settings
from django.utils.translation import ugettext_lazy

from crispy_forms.helper import FormHelper
from crispy_forms_foundation.layout import Layout, Fieldset, Submit, Row, Column, Field


class ApplicationFormHelper(FormHelper):
    form_action = ''
    layout_fields = [
        Row(
            Column(
                Field('first_name', placeholder=ugettext_lazy(u'First name')),
                css_class='large-6 medium-6 small-12',
            ),
            Column(
                Field('last_name', placeholder=ugettext_lazy('Last name')),
                css_class='large-6 medium-6 small-12',
            ),
            Column(
                Field('email', placeholder=ugettext_lazy('Email')),
                css_class='large-6 medium-6 small-12',
            ),
            Column(
                Field('phone', placeholder=ugettext_lazy('Phone')),
                css_class='large-6 medium-6 small-12'),
            Column(
                Field('message', placeholder=ugettext_lazy('Message')),
                css_class='large-12 medium-12 small-12',
            ),
            Fieldset(
                ugettext_lazy(u'Attachments'),
                Column(
                    Field('cv', placeholder=ugettext_lazy(u'Resumé')),
                    css_class='large-4 medium-12 small-12 '),
                Column(
                    Field('cover_letter', placeholder=ugettext_lazy(u'Cover letter')),
                    css_class='large-4 medium-12 small-12 '),
                Column(
                    Field('other_document', placeholder=ugettext_lazy(u'Other documents')),
                    css_class='large-4 medium-12 small-12 '),
            ),
        )
    ]
    if getattr(settings, 'JOB_OFFER_RGPD_ENABLED', False):
        layout_fields.append(
            Row(
                Column(
                    Field('rgpd', required=""),
                    css_class='small-12 rgpd',
                ),
            )
        )
    layout_fields.append(
        Row(
            Column(
                Submit('submit', ugettext_lazy('OK')),
                css_class='large-12 medium-12 small-12 text-center'),
        ),
    )
    layout = Layout(*layout_fields)


class SearchFormHelper(FormHelper):
    form_action = '.'
    form_method = 'get'

    layout = Layout(
        Column(
            Field('keywords', placeholder=ugettext_lazy('Keywords')),
            css_class='large-3 medium-4 small-12',
        ),
        Column(
            Field('contract_type', placeholder=ugettext_lazy('Contract Type')),
            css_class='large-4 medium-3 small-12',
        ),
        Column(
            Field('location', placeholder=ugettext_lazy('Location')),
            css_class='large-4 medium-3 small-12',
        ),
        Column(
            Submit('search', ugettext_lazy('Find')),
            css_class='large-1 medium-2 small-12',
        ),
    )
